@@ -29,13 +29,17 @@ def main(global_config, **settings):
     config.add_translation_dirs('pyrone:locale/')
     config.scan()
     config.add_static_view('static', 'pyrone:static')
-    routes = [('blog_latest', '/'),
+    routes = [
+              ('static_favicon_png', '/favicon.png'),
+              ('static_favicon_ico', '/favicon.ico'),
+              ('blog_latest', '/'),
               ('blog_latest_rss', '/rss/latest'),
               ('blog_tag_articles', '/tag/{tag}'),
               ('blog_write_article', '/write'), 
               ('blog_go_article', '/article/{article_id:\d+}'),
               ('blog_view_article', '/{shortcut_date:\d\d\d\d/\d\d/\d\d}/{shortcut}'),
               ('blog_view_moderation_queue', '/comments/moderation'),
+              ('blog_edit_article_ajax', '/article/{article_id:\d+}/edit/ajax'),
               ('blog_edit_article', '/article/{article_id:\d+}/edit'),
               ('blog_preview_article', '/preview/article'),
               ('blog_article_delete_ajax', '/article/{article_id:\d+}/delete/ajax'),
@@ -90,4 +94,4 @@ def main(global_config, **settings):
     #config.add_view('pyrone.views.latest',
     #                route_name='latest',
     #                renderer='templates/mytemplate.pt')
-    return config.make_wsgi_app()
\ No newline at end of file
+    return config.make_wsgi_app()
